@@ -94,4 +94,4 @@ class Scene(Entity, ProjectMixin, CodeMixin):
     def __hash__(self):
         """the overridden __hash__ method
         """
-        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+        return super(Scene, self).__hash__()
