@@ -92,4 +92,4 @@ class Sequence(Task, CodeMixin):
     def __hash__(self):
         """the overridden __hash__ method
         """
-        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+        return super(Sequence, self).__hash__()
